netapp_ontap.models.timezone_cluster API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.timezone_cluster`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class TimezoneClusterSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the TimezoneCluster object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `name GET POST PATCH`

    The ONTAP time zone name or identification in either IANA time zone format "Area/Location", or an ONTAP traditional time zone. The initial first node in cluster setting for time zone is "Etc/UTC". "Etc/UTC" is the IANA timezone "Area/Location" specifier for Coordinated Universal Time (UTC), which is an offset of 0.

    ### IANA time zone format

    The IANA time zone, formatted as "Area/Location", is based on geographic areas that have had the same time zone offset for many years. "Location" represents a compound name using additional forward slashes. An example of the "Area/Location" time zone is "America/New_York" and represents most of the United States Eastern Time Zone. Examples of "Area/Location" with "Location" as a compound name are "America/Argentina/Buenos_Aires" and "America/Indiana/Indianapolis".

    ### ONTAP traditional time zone

    Examples of the traditional time zones are "EST5EDT" for the United States Eastern Time Zone and "CET" for Central European Time Zone.

    Example: America/New_York